Why Janis
===========

Janis is a workflow system built in Python, designed to help you do Computational Analysis. Specifically, Janis is a Python Framework that helps you to quickly build workflows that can be run portably across HPCs and cloud infrastructure.

We believe Janis is a great choice for writing workflows and building analysis for a few reasons:

- Familiar Python interface
- Prebuilt workflows and tools for Bioinformatics
- Structured and Publishable
- Portable and Reproducible through Containers


Familiar interface
-------------------

We think using ``Python`` is great way to build workflows. Python's syntax is simple enough that those unfamiliar can follow, and allows researcher's to contribute to the registry of domain-specific tools and data types.

Janis can generate CWL and WDL (Common Workflow Language / Workflow Description Language), so you don't need to learn other workflow language.


Prebuilt workflows and tools for Bioinformatics
------------------------------------------------------

We've built WGS variant calling pipelines for **Germline** and **Somatic** analysis that are ready to run anywhere. Additionally, we have a registry of commonly used Bioinformatics Tools that are used in your workflows.



Structured and Publishable
------------------------------

Janis workflows lead you to structure your workflows in composable ways. This helps to reuse components of your workflow